<?php
/**
 * This file contains the class admin functions.
 *
 * @package learndash-reports-by-wisdmlabs
 */

namespace WisdmReportsLearndash;

class Admin_Functions {

	protected static $instance = null;

	/**
	 * This function has been used to create the static instance of the admin functions class.
	 */
	public static function instance() {
		if ( is_null( self::$instance ) ) {
			self::$instance = new self();
		}
		return self::$instance;
	}

	/**
	 * This is the constructor for the class that will instantiate all processes related to the class.
	 */
	public function __construct() {
		$this->init_hooks();
	}

	/**
	 * This method is used to add all the admin related actions and filter hooks.
	 */
	public function init_hooks() {
		add_action( 'wp_ajax_wrld_page_visit', array( $this, 'update_reporting_page_visit' ) );
		add_action( 'wp_ajax_wrld_notice_action', array( $this, 'wrld_notice_action' ) );
		add_action( 'init', array( $this, 'wrld_create_patterns_page' ), 99 );
		//settings page ajax actions
		add_action( 'wp_ajax_wrld_skip_license_activation', array( $this, 'wrld_skip_license_activation' ) );
		add_action( 'wp_ajax_wrld_license_activate', array( $this, 'wrld_license_activate' ) );
		add_action( 'wp_ajax_wrld_license_deactivate', array( $this, 'wrld_license_deactivate' ) );
		add_action( 'wp_ajax_wrld_set_configuration', array( $this, 'wrld_set_configuration' ) );
		add_action( 'wp_ajax_wrld_update_settings', array( $this, 'wrld_update_settings' ) );
		add_action( 'wp_ajax_wrld_license_page_visit', array( $this, 'wrld_license_page_visit' ) );
		//Welcome modal
		add_action( 'wp_ajax_wrld_welcome_modal_action', array( $this, 'wrld_welcome_modal_action' ) );
	}

	/**
	 * This action is hooked to the ajax callback action 'wp_ajax_wrld_page_visit',
	 * on called verifies if the request is from the correct source & update teh value for the
	 * option 'wrld_reporting_page_visited'.
	 */
	public static function update_reporting_page_visit() {
		$nonce = ! empty( $_REQUEST['wp_nonce'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['wp_nonce'] ) ) : '';
		if ( wp_verify_nonce( $nonce, 'reports-firrst-install-modal' ) ) {
			//update_option( 'wrld_reporting_page_visited', 2 );
			\wp_send_json_success();
		}
		\wp_send_json_error();
	}


	/**
	 * This action is hooked to the ajax callback action 'wp_ajax_wrld_notice_action',
	 * on called verifies if the request is from the correct source & update the value for the
	 * option 'wrld_last_skipped_on'.
	 */
	public static function wrld_notice_action() {
		$nonce = ! empty( $_REQUEST['wp_nonce'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['wp_nonce'] ) ) : '';
		if ( wp_verify_nonce( $nonce, 'wrld-review-notice' ) ) {
			$user_action = sanitize_text_field( wp_unslash( $_REQUEST['user_action'] ) );
			switch ( $user_action ) {
				case 'wisdm-reports-for-ld-remind-later':
				case 'wisdm-reports-for-ld-post-review':
				case 'close':
					update_option( 'wrld_last_skipped_on', time() );
					break;
				default:
					update_option( 'ld-reports-review-dismissed', time() );
					break;
			}
			\wp_send_json_success();
		}
		\wp_send_json_error();
	}

	public function show_wisdm_reports_submenu() {
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'Reports', 'learndash-reports-by-wisdmlabs' ); ?></h1>
			<?php
			$dashboard_id = get_option( 'ldrp_reporting_page', false );
			if ( ! $dashboard_id || 'publish' !== get_post_status( $dashboard_id ) ) {
				?>
				<p><?php esc_html_e( 'The page seems to have been deleted/removed. Please click on the link below to create the page manually.', 'learndash-reports-by-wisdmlabs' ); ?></p>
				<a href="<?php echo esc_attr( add_query_arg( array( 'create_wisdm_reports' => true ) ) ); ?>"><?php esc_html_e( 'Create Reports Dashboard', 'learndash-reports-by-wisdmlabs' ); ?></a>
				<?php
			} else {
				?>
				<p><a class="primary-button primary-btn components-button is-primary" href="<?php echo esc_url( get_permalink( $dashboard_id ) ); ?>" target="_blank" style="background:#007cba;color:#fff;text-decoration:none;text-shadow:none;outline:1px solid transparent;padding:6px 12px;border-radius:2px;"><?php esc_html_e( 'Launch Reports Dashboard', 'learndash-reports-by-wisdmlabs' ); ?></a></p>
				<?php
			}
			?>
		</div>
		<?php
	}

	/**
	 * This function creates the page with the default WRLD pattern when a get parameter 'create_wisdm_reports' is set.
	 */
	public function wrld_create_patterns_page() {
		$new_page_creation = filter_input( INPUT_GET, 'create_wisdm_reports', FILTER_VALIDATE_BOOLEAN );
		$created_page      = get_option( 'ldrp_reporting_page', false );

		if ( $created_page && 'publish' !== get_post_status( $created_page ) ) {
			if ( ! empty( $new_page_creation ) ) {
				wrld_create_patterns_page( true );
				add_action( 'admin_notices', '\WisdmReportsLearndash\Admin_Functions::report_page_creation_notice' );
			}
		} elseif ( false == $created_page ) {
			wrld_create_patterns_page( false );
				add_action( 'admin_notices', '\WisdmReportsLearndash\Admin_Functions::report_page_creation_notice' );
		}
	}

	/**
	 * The function checks if the plugin specified is installed on the website.
	 * - Currently works only for the WordPress single site.
	 *
	 * @param $plugin_slug plugin path and plugin file name, ex : learndash-reports-pro/learndash-reports-pro.php.
	 */
	public static function is_plugin_installed( $plugin_slug ) {
		if ( empty( $plugin_slug ) ) {
			return false;
		}

		// Check if needed functions exists - if not, require them
		if ( ! function_exists( 'get_plugins' ) || ! function_exists( 'is_plugin_active' ) ) {
			require_once ABSPATH . 'wp-admin/includes/plugin.php';
		}

		$installed_plugins = get_plugins();
		return array_key_exists( $plugin_slug, $installed_plugins ) || in_array( $plugin_slug, $installed_plugins, true );
	}

	/**
	 * Shows admin a notice on the admin dashboard.
	 */
	public static function report_page_creation_notice() {
		echo '<div class="notice notice-success is-dismissible"><p>';
		echo esc_html__( 'Successfully created WISDM Reports For LearnDash page', 'learndash-reports-by-wisdmlabs' );
		echo '</p></div>';
	}

	/****************************************
	 * Actions for admin dashboard settings *
	 ****************************************/

	public static function wrld_skip_license_activation() {
		$nonce       = isset( $_REQUEST['nonce'] ) ? sanitize_text_field( $_REQUEST['nonce'] ) : '';
		$nonce_valid = wp_verify_nonce( $nonce, 'wrld-admin-settings' );
		if ( ! $nonce_valid ) {
			wp_send_json_error(
				array(
					'success' => true,
					'message' => __(
						'Nonce verification fialed',
						'learndash-reports-by-wisdmlabs'
					),
				)
			);
		}
		$settings_data                            = get_option( 'wrld_settings', array() );
		$settings_data['skip-license-activation'] = true;
		update_option( 'wrld_settings', $settings_data );
		wp_send_json_success( array( 'success' => true ) );
	}

	/**
	 * A function hooked to the ajax action wrld_license_activate,
	 * resposible for initiating the activation request for the
	 * reports pro plugin license key.
	 *
	 * @since 1.2.0
	 */
	public static function wrld_license_activate() {
		$str              = get_home_url();
		$site_url         = preg_replace( '#^https?://#', '', $str );
		$ldrp_plugin_data = array(
			'pluginShortName'   => 'WISDM Reports for LearnDash PRO',
			'pluginSlug'        => 'learndash-reports-pro',
			'itemId'            => 707478,
			'pluginVersion'     => LDRP_PLUGIN_VERSION,
			'pluginName'        => 'WISDM Reports for LearnDash PRO',
			'storeUrl'          => 'https://wisdmlabs.com/license-check/',
			'siteUrl'           => $site_url,
			'authorName'        => 'WisdmLabs',
			'pluginTextDomain'  => 'learndash-reports-pro',
			'baseFolderUrl'     => plugins_url( '/', __FILE__ ),
			'baseFolderDir'     => untrailingslashit( plugin_dir_path( __FILE__ ) ),
			'isTheme'           => false,
			'themeChangelogUrl' => 'https://wisdmlabs.com/elumine/documentation/change-log/',
			'mainFileName'      => 'learndash-reports-pro.php',
		);
		$nonce            = isset( $_REQUEST['nonce'] ) ? sanitize_text_field( $_REQUEST['nonce'] ) : '';
		$license_key      = isset( $_REQUEST['license_key'] ) ? sanitize_text_field( $_REQUEST['license_key'] ) : '';
		$nonce_valid      = wp_verify_nonce( $nonce, 'wrld-admin-settings' );
		$license_data     = '';

		if ( ! $nonce_valid ) {
			wp_send_json_error(
				array(
					'success' => false,
					'message' => __(
						'Nonce verification fialed',
						'learndash-reports-by-wisdmlabs'
					),
				)
			);
		}

		if ( defined( 'LDRP_PLUGIN_VERSION' ) && ! empty( $license_key ) ) {
			$_POST['edd_learndash-reports-pro_license_key'] = $license_key;
			require_once LDRP_PLUGIN_DIR . 'licensing/class-wdm-license.php';
			require_once LDRP_PLUGIN_DIR . 'licensing/class-wdm-add-license-data.php';
			$license_manager = new \Licensing\WdmAddLicenseData( $ldrp_plugin_data );
			if ( method_exists( $license_manager, 'activate_license' ) ) {
				$license_manager->activate_license();
				$license_data = \Licensing\WdmGetLicenseData::get_data_from_db( $ldrp_plugin_data );
			} elseif ( method_exists( $license_manager, 'activateLicense' ) ) {
				$license_manager->activateLicense();
				$license_data = \Licensing\WdmGetLicenseData::getDataFromDb( $ldrp_plugin_data );
			} else {
				wp_send_json_error( array( 'status' => 'failed' ) );
			}
		}

		wp_send_json_success( array( 'license_data' => $license_data ) );
	}

	/**
	 * A function hooked to the ajax action wrld_license_deactivate,
	 * resposible for initiating the deactivation request for the
	 * reports pro plugin license key.
	 *
	 * @since 1.2.0
	 */
	public static function wrld_license_deactivate() {
		$str              = get_home_url();
		$site_url         = preg_replace( '#^https?://#', '', $str );
		$ldrp_plugin_data = array(
			'pluginShortName'   => 'WISDM Reports for LearnDash PRO',
			'pluginSlug'        => 'learndash-reports-pro',
			'itemId'            => 707478,
			'pluginVersion'     => LDRP_PLUGIN_VERSION,
			'pluginName'        => 'WISDM Reports for LearnDash PRO',
			'storeUrl'          => 'https://wisdmlabs.com/license-check/',
			'siteUrl'           => $site_url,
			'authorName'        => 'WisdmLabs',
			'pluginTextDomain'  => 'learndash-reports-pro',
			'baseFolderUrl'     => plugins_url( '/', __FILE__ ),
			'baseFolderDir'     => untrailingslashit( plugin_dir_path( __FILE__ ) ),
			'isTheme'           => false,
			'themeChangelogUrl' => 'https://wisdmlabs.com/elumine/documentation/change-log/',
			'mainFileName'      => 'learndash-reports-pro.php',
		);
		$nonce            = isset( $_REQUEST['nonce'] ) ? sanitize_text_field( $_REQUEST['nonce'] ) : '';
		$nonce_valid      = wp_verify_nonce( $nonce, 'wrld-admin-settings' );

		if ( ! $nonce_valid ) {
			wp_send_json_error(
				array(
					'success' => false,
					'message' => __(
						'Nonce verification fialed',
						'learndash-reports-by-wisdmlabs'
					),
				)
			);
		}

		if ( defined( 'LDRP_PLUGIN_VERSION' ) ) {
			require_once LDRP_PLUGIN_DIR . 'licensing/class-wdm-license.php';
			require_once LDRP_PLUGIN_DIR . 'licensing/class-wdm-add-license-data.php';

			$license_manager = new \Licensing\WdmAddLicenseData( $ldrp_plugin_data );

			if ( method_exists( $license_manager, 'activate_license' ) ) {
				$license_manager->deactivate_license();
				$license_data = \Licensing\WdmGetLicenseData::get_data_from_db( $ldrp_plugin_data );
			} elseif ( method_exists( $license_manager, 'activateLicense' ) ) {
				$license_manager->deactivateLicense();
				$license_data = \Licensing\WdmGetLicenseData::getDataFromDb( $ldrp_plugin_data );
			} else {
				wp_send_json_error( array( 'status' => 'failed' ) );
			}
		}

		wp_send_json_success( array( 'license_data' => $license_data ) );
	}

	/**
	 * A function hooked to the ajax action wrld_set_configuration,
	 * resposible for setting up the configuration which enables inclusion
	 * of the reports page link in the primary menu.
	 *
	 * @since 1.2.0
	 */
	public static function wrld_set_configuration() {
		$nonce       = isset( $_REQUEST['nonce'] ) ? sanitize_text_field( $_REQUEST['nonce'] ) : '';
		$nonce_valid = wp_verify_nonce( $nonce, 'wrld-admin-settings' );
		if ( ! $nonce_valid ) {
			wp_send_json_error(
				array(
					'success' => true,
					'message' => __(
						'Nonce verification fialed',
						'learndash-reports-by-wisdmlabs'
					),
				)
			);
		}
		$settings_data                             = get_option( 'wrld_settings', array() );
		$settings_data['wrld-menu-config-setting'] = 'true' == sanitize_text_field( $_REQUEST['add_in_menu'] ) ? true : false;
		update_option( 'wrld_settings', $settings_data );
		wp_send_json_success( array( 'success' => true ) );
	}

	/**
	 * A function hooked to the ajax action wrld_update_settings,
	 * resposible for setting up the configuration which enables inclusion
	 * of the reports page link in the primary menu.
	 *
	 * @since 1.2.0
	 */
	public static function wrld_update_settings() {
		$nonce       = isset( $_REQUEST['nonce'] ) ? sanitize_text_field( $_REQUEST['nonce'] ) : '';
		$nonce_valid = wp_verify_nonce( $nonce, 'wrld-admin-settings' );
		if ( ! $nonce_valid ) {
			wp_send_json_error(
				array(
					'success' => false,
					'message' => __(
						'Nonce verification fialed',
						'learndash-reports-by-wisdmlabs'
					),
				)
			);
		}
		$settings_data                             = get_option( 'wrld_settings', array() );
		$access_for_group_leader                   = 'true' == sanitize_text_field( $_REQUEST['access_to_group_leader'] ) ? true : false;
		$access_for_wdm_instructor                 = 'true' == sanitize_text_field( $_REQUEST['access_to_wdm_instructor'] ) ? true : false;
		$settings_data['wrld-menu-config-setting'] = 'true' == sanitize_text_field( $_REQUEST['add_in_menu'] ) ? true : false;
		$settings_data['dashboard-access-roles']   = array(
			'group_leader'   => $access_for_group_leader,
			'wdm_instructor' => $access_for_wdm_instructor,
		);
		update_option( 'wrld_settings', $settings_data );
		wp_send_json_success( array( 'settings_data' => $settings_data ) );

	}


	public function wrld_license_page_visit() {
		$nonce       = isset( $_REQUEST['nonce'] ) ? sanitize_text_field( $_REQUEST['nonce'] ) : '';
		$nonce_valid = wp_verify_nonce( $nonce, 'wrld-admin-settings' );
		if ( ! $nonce_valid ) {
			wp_send_json_error(
				array(
					'success' => false,
					'message' => __(
						'Nonce verification fialed',
						'learndash-reports-by-wisdmlabs'
					),
				)
			);
		}
		$page          = isset( $_REQUEST['page'] ) ? sanitize_text_field( $_REQUEST['page'] ) : '';
		$wrld_pages    = array( 'wrld-dashboard-page', 'wrld-license-activation', 'wrld-other-plugins', 'wrld-help', 'wrld-settings' );
		$settings_data = get_option( 'wrld_settings', array() );
		if ( in_array( $page, $wrld_pages, true ) ) {
			$settings_data['skip-license-activation'] = true;
		}
		update_option( 'wrld_settings', $settings_data );

		wp_send_json_success( array( 'settings_data' => $settings_data ) );
	}

	public static function wrld_welcome_modal_action() {
		$nonce       = isset( $_REQUEST['nonce'] ) ? sanitize_text_field( $_REQUEST['nonce'] ) : '';
		$nonce_valid = wp_verify_nonce( $nonce, 'wrld-welcome-modal' );
		if ( ! $nonce_valid ) {
			wp_send_json_error(
				array(
					'success' => true,
					'message' => __(
						'Nonce verification fialed',
						'learndash-reports-by-wisdmlabs'
					),
				)
			);
		}
		if ( defined( 'LDRP_PLUGIN_VERSION' ) ) {
			update_option( 'wrld_visited_dashboard', 'pro' );
		} else {
			update_option( 'wrld_visited_dashboard', 'free' );
		}
	}

}

\WisdmReportsLearndash\Admin_Functions::instance();
