<?php

namespace WRLDAdmin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! class_exists( 'DashboardPage' ) ) {

	/**
	* Class for showing tabs of WRLD.
	*/
	class DashboardPage {

		public function __construct() {
			wp_enqueue_style( 'wrld_admin_dashboard_contentainer_style', WRLD_REPORTS_SITE_URL . '/includes/admin/dashboard/assets/css/content-page.css', array(), WRLD_PLUGIN_VERSION );
		}

		public static function render() {
			$settings_data = get_option( 'wrld_settings', false );
			$wrld_page     = get_option( 'ldrp_reporting_page', false );
			?>
			<div class='wrld-dashboard-page-container'>
				<?php
				if ( $wrld_page && $wrld_page > 0 && 'publish' === get_post_status( $wrld_page ) ) {
					self::content_when_configured( $wrld_page );
				} else {
					self::content_when_not_configured( $wrld_page, $settings_data );
				}
				self::content_sidebar();
				?>
			</div>
			<?php
		}

		public static function content_when_not_configured( $wrld_page, $settings_data ) {
			$page_link     = get_edit_post_link( $wrld_page );
			$add_menu_link = isset( $settings_data['wrld-menu-config-setting'] ) && ( 'true' == $settings_data['wrld-menu-config-setting'] ) ? true : false;
			$action_text   = __( 'Configure dashboard', 'learndash-reports-by-wisdmlabs' );
			if ( false == $wrld_page || null == $page_link ) {
				$action_text = __( 'Create Reports Dashboard', 'learndash-reports-by-wisdmlabs' );
				$page_link   = add_query_arg( array( 'create_wisdm_reports' => true ) );
			}
			?>
				<div class='wrld-dashboard-page-content'>
					<div>
						<span class='wrld-dashboard-text'> <?php esc_html_e( 'The Reports Dashboard can be accessed at any time from here.', 'learndash-reports-by-wisdmlabs' ); ?> </span>
						<br/>
						<span class='wrld-dashboard-text'> <?php esc_html_e( 'Configure the setting below and launch the Reports Dashboard.', 'learndash-reports-by-wisdmlabs' ); ?> </span>
						<br/>
						<div class='wrld-dashboard-note-container'>
							<span class='wrld-dashboard-note'><strong> <?php esc_html_e( 'Note: ', 'learndash-reports-by-wisdmlabs' ); ?> </strong></span>
							<span class='wrld-dashboard-note'> <?php esc_html_e( 'Checking the setting below and launching the dashboard will create a page on the front-end of your site which will include the Reports Dashboard and will also add the link to this page to your Header Menu.', 'learndash-reports-by-wisdmlabs' ); ?> </span>
						</div>
						<div class='wrld-dashboard-config-setting'>
							<?php self::get_add_menu_link_setting( $add_menu_link ); ?>
						</div>
						<div class='wrld-dashboard-note-container'>
							<span class='wrld-dashboard-note'> <?php esc_html_e( 'To control the accessibility of the Reports Dashboard for Group Leaders and other user roles go to ', 'learndash-reports-by-wisdmlabs' ); ?> </span>
							<span class='wrld-dashboard-note'> <a href='admin.php?page=wrld-settings'><?php esc_html_e( 'more settings.', 'learndash-reports-by-wisdmlabs' ); ?> </a></span>
						</div>
					</div>
					<div class='wrld-dashboard-action'>
						<a href="<?php echo esc_attr( $page_link ); ?>">
						<button class='wrld-dashboard-button-action set-config'><?php echo esc_html( $action_text ); ?></button>
						</a>
					</div>
				</div>
			<?php
		}

		public static function content_when_configured( $wrld_page ) {
			$page_link = get_post_permalink( $wrld_page );
			?>
				<div class='wrld-dashboard-page-content'>
					<div>
						<span class='wrld-dashboard-text'> <?php esc_html_e( 'The Reports Dashboard can be accessed at any time from here.', 'learndash-reports-by-wisdmlabs' ); ?> </span>
					</div>
					<div class='wrld-dashboard-action'>
						<a href="<?php echo esc_attr( $page_link ); ?>">
						<button class='wrld-dashboard-button-action'><?php esc_html_e( 'View dashboard', 'learndash-reports-by-wisdmlabs' ); ?></button>
						</a>
					</div>
				</div>
			<?php
		}

		public static function content_sidebar() {
			?>
				<div class='wrld-dashboard-page-sidebar'>
					<?php self::sidebar_block_upgrade(); ?>
					<?php self::sidebar_block_help(); ?>
				</div>
			<?php
		}

		public static function sidebar_block_upgrade() {
			if ( defined( 'LDRP_PLUGIN_VERSION' ) ) {
				return '';
			} else {
				?>
				<div class='wrld-sidebar-block'>
					<div class='wrld-sidebar-block-head'>
						<div class='wrld-sidebar-head-icon'>
							<span class='upgrade-icon'></span>
						</div>
						<div class='wrld-sidebar-head-text'>
							<span><?php esc_html_e( 'Upgrade your FREE Wisdm Reports Plugin to PRO!', 'learndash-reports-by-wisdmlabs' ); ?></span>
						</div>
					</div>
					<div class='wrld-sidebar-body'>
						<div class='wrld-sidebar-body-text'>
							<span><?php esc_html_e( 'Click the button below to upgrade your FREE Wisdm Reports Plugin to PRO!', 'learndash-reports-by-wisdmlabs' ); ?></span>
						</div>
						<a href="https://wisdmlabs.com/reports-for-learndash/?utm_source=wrld&utm_medium=wrld_in_plugin_settings_tab&utm_campaign=wrld_in_plugin_settings_tab&utm_id=20062022&utm_term=wrld_in_plugin_settings_tab#pricing" target='__blank'>
							<button class='wrld-sidebar-body-button'><?php esc_html_e( 'Upgrade to PRO', 'learndash-reports-by-wisdmlabs' ); ?></button>
						</a>
					</div>
				</div>
				<?php
			}
		}

		public static function sidebar_block_help() {
			?>
			<div class='wrld-sidebar-block'>
					<div class='wrld-sidebar-block-head'>
						<div class='wrld-sidebar-head-icon'>
							<span class='help-icon'></span>
						</div>
						<div class='wrld-sidebar-head-text'>
							<span><?php esc_html_e( 'Looking for help?', 'learndash-reports-by-wisdmlabs' ); ?></span>
						</div>
					</div>
					<div class='wrld-sidebar-body'>
						<div class='wrld-sidebar-body-text'>
							<span><?php esc_html_e( 'Need help with creating separate reports dashboards for different user roles?', 'learndash-reports-by-wisdmlabs' ); ?></span>
						</div>
						<ul>
						  <li><a href="https://wisdmlabs.com/docs/product/wisdm-learndash-reports/lr-getting-started/" target='__blank'><?php esc_html_e( 'Getting started', 'learndash-reports-by-wisdmlabs' ); ?></a></li>
						  <li><a href="https://wisdmlabs.com/docs/product/wisdm-learndash-reports/gutenberg-blocks/" target='__blank'><?php esc_html_e( 'List of Available Reports', 'learndash-reports-by-wisdmlabs' ); ?></a></li>
						</ul>
					</div>
				</div>
			<?php
		}

		public static function get_add_menu_link_setting( $enabled ) {
			?>
				<label for='wrld-menu-config-setting'>
					<input type="checkbox" name="wrld-menu-config-setting" id="wrld-menu-config-setting" class="dashicons" <?php checked( $enabled ); ?>>
					<span><?php esc_html_e( 'Add the link of the Reports Dashboard to the Header Menu', 'learndash-reports-by-wisdmlabs' ); ?></span>
				</label>
			<?php
		}

	}
}
