<?php

namespace WRLDAdmin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! class_exists( 'SettingsPage' ) ) {

	/**
	* Class for showing tabs of WRLD.
	*/
	class SettingsPage {

		public function __construct() {
			wp_enqueue_style( 'wrld_admin_dashboard_contentainer_style', WRLD_REPORTS_SITE_URL . '/includes/admin/dashboard/assets/css/content-page.css', array(), WRLD_PLUGIN_VERSION );
		}

		public static function style_display( $display, $value = 'inline-block', $hide = true ) {
			if ( $display ) {
				return 'display:' . $value . ';';
			} elseif ( $hide ) {
				return 'display:none';
			}
		}

		public static function render() {
			?>
			<div class='wrld-dashboard-page-container'>
				<?php
					self::content_main();
					self::content_sidebar();
				?>
			</div>
			<?php
		}

		public static function content_main() {
			$settings_data = get_option( 'wrld_settings', array() );
			?>
				<div class='wrld-dashboard-page-content'>
					<div>
						<span class='wrld-dashboard-text license'> <?php esc_html_e( 'Add dashboard link to Header', 'learndash-reports-by-wisdmlabs' ); ?> </span>
						<br/>
						<div class='wrld-dashboard-config-setting'>
							<?php
							self::get_add_menu_link_setting( $settings_data );
							self::get_accessibility_setting( $settings_data );
							?>
						</div>
					</div>
					<div>
						<button id='wrld-action-update-settings' disabled><?php esc_html_e( 'Apply', 'learndash-reports-by-wisdmlabs' ); ?></button>
					</div>
				</div>
			<?php
		}

		public static function content_sidebar() {
			?>
				<div class='wrld-dashboard-page-sidebar'>
					<?php self::sidebar_block_upgrade(); ?>
					<?php self::sidebar_block_help(); ?>
				</div>
			<?php
		}

		public static function sidebar_block_upgrade() {
			if ( defined( 'LDRP_PLUGIN_VERSION' ) ) {
				return '';
			} else {
				?>
				<div class='wrld-sidebar-block'>
					<div class='wrld-sidebar-block-head'>
						<div class='wrld-sidebar-head-icon'>
							<span class='upgrade-icon'></span>
						</div>
						<div class='wrld-sidebar-head-text'>
							<span><?php esc_html_e( 'Upgrade your FREE Wisdm Reports Plugin to PRO!', 'learndash-reports-by-wisdmlabs' ); ?></span>
						</div>
					</div>
					<div class='wrld-sidebar-body'>
						<div class='wrld-sidebar-body-text'>
							<span><?php esc_html_e( 'Click the button below to upgrade your FREE Wisdm Reports Plugin to PRO!', 'learndash-reports-by-wisdmlabs' ); ?></span>
						</div>
						<a href="https://wisdmlabs.com/reports-for-learndash/?utm_source=wrld&utm_medium=wrld_in_plugin_settings_tab&utm_campaign=wrld_in_plugin_settings_tab&utm_id=20062022&utm_term=wrld_in_plugin_settings_tab#pricing" target='__blank'>
							<button class='wrld-sidebar-body-button'><?php esc_html_e( 'Upgrade to PRO', 'learndash-reports-by-wisdmlabs' ); ?></button>
						</a>
					</div>
				</div>
				<?php
			}
		}

		public static function sidebar_block_help() {
			?>
			<div class='wrld-sidebar-block'>
					<div class='wrld-sidebar-block-head'>
						<div class='wrld-sidebar-head-icon'>
							<span class='help-icon'></span>
						</div>
						<div class='wrld-sidebar-head-text'>
							<span><?php esc_html_e( 'Looking for help?', 'learndash-reports-by-wisdmlabs' ); ?></span>
						</div>
					</div>
					<div class='wrld-sidebar-body'>
						<div class='wrld-sidebar-body-section'>
							<div class='wrld-sidebar-body-text'>
								<span><?php esc_html_e( 'Need help with the plugin configuration?', 'learndash-reports-by-wisdmlabs' ); ?></span>
							</div>
							<ul>
							  <li><a href="https://wisdmlabs.com/docs/article/wisdm-learndash-reports/lr-getting-started/configuration-accessibility-settings/" target='__blank'><?php esc_html_e( 'Settings & access configuration', 'learndash-reports-by-wisdmlabs' ); ?></a></li>
							  <!-- <li><a href="#" target='__blank'><?php esc_html_e( 'Document Link 2', 'learndash-reports-by-wisdmlabs' ); ?></a></li> -->
							</ul>
						</div>
						<div class='wrld-sidebar-body-section'>
							<div class='wrld-sidebar-body-text'>
								<span><?php esc_html_e( 'Need help with creating separate reports dashboards for different user roles?', 'learndash-reports-by-wisdmlabs' ); ?></span>
							</div>
							<ul>
							  <li><a href="https://wisdmlabs.com/docs/article/wisdm-learndash-reports/how-to-create-multiple-user-specific-dashboards/" target='__blank'><?php esc_html_e( 'Create Multiple Dashboards', 'learndash-reports-by-wisdmlabs' ); ?></a></li>
							  <!-- <li><a href="#" target='__blank'><?php esc_html_e( 'Document Link 2', 'learndash-reports-by-wisdmlabs' ); ?></a></li> -->
							</ul>
						</div>
					</div>
				</div>
			<?php
		}

		public static function get_add_menu_link_setting( $settings_data ) {
			$add_menu_link = isset( $settings_data['wrld-menu-config-setting'] ) && ( 'true' == $settings_data['wrld-menu-config-setting'] ) ? true : false;
			?>
				<div class='wrld-menu-config-setting-section'>
					<label for='wrld-menu-config-setting' class="checkbox-label <?php echo esc_attr( $add_menu_link ? '' : 'no-access' ); ?>">
						<input type="checkbox" name="wrld-menu-config-setting" id="wrld-menu-config-setting" class="dashicons" <?php checked( $add_menu_link ); ?> >
						<span><?php esc_html_e( 'Add the link of the Reports Dashboard to the Header Menu', 'learndash-reports-by-wisdmlabs' ); ?></span>
					</label>
				</div>
			<?php
		}

		public static function get_accessibility_setting( $settings_data ) {
			$instructor_role_status = defined( 'INSTRUCTOR_ROLE_PLUGIN_VERSION' ) ? '' : 'disabled';
			$gl_access              = isset( $settings_data['dashboard-access-roles'] ) && ( 'true' == $settings_data['dashboard-access-roles']['group_leader'] ) ? true : false;
			$wdm_instructor_access  = isset( $settings_data['dashboard-access-roles'] ) && ( 'true' == $settings_data['dashboard-access-roles']['wdm_instructor'] ) ? true : false;
			if ( ! isset( $settings_data['dashboard-access-roles'] ) ) {
				$gl_access             = true;
				$wdm_instructor_access = true;
			}
			?>
				<div class='wrld-accessibility-setting-section'>
					<div>
						<span class='wrld-dashboard-text license'> <?php esc_html_e( 'Dashboard accessibility', 'learndash-reports-by-wisdmlabs' ); ?> </span>
					</div>
					<div class='wrld-dashboard-note-container'>
						<span class='wrld-dashboard-text'> <?php esc_html_e( 'The user roles selected here and the admin will have access to the Reports Dashboard.', 'learndash-reports-by-wisdmlabs' ); ?> </span>
					</div>
					<div>
						<label for='wrld-menu-access-setting-group-leader' class="checkbox-label <?php echo esc_attr( $gl_access ? '' : 'no-access' ); ?>">
							<input type="checkbox" name="wrld-menu-access-setting-group-leader" id="wrld-menu-access-setting-group-leader" class="dashicons" <?php checked( $gl_access ); ?>>
							<span><?php esc_html_e( 'Group Leader', 'learndash-reports-by-wisdmlabs' ); ?></span>
							<p class='wrld-access-status wrld-access-status-enabled wrld-group-leader-enabled' style='<?php echo esc_attr( self::style_display( $gl_access ) ); ?>'><span class="dashicons dashicons-yes"></span><span><?php esc_html_e( 'Access Active', 'learndash-reports-by-wisdmlabs' ); ?></span></p>
							<p class='wrld-access-status wrld-access-status-disabled wrld-group-leader-disabled' style='<?php echo esc_attr( self::style_display( ! $gl_access ) ); ?>'><span class="dashicons dashicons-no"></span><span><?php esc_html_e( 'Access Inactive', 'learndash-reports-by-wisdmlabs' ); ?></span></p>
						</label>
					</div>
					<div>
						<label for='wrld-menu-access-setting-wdm-instructor' class="checkbox-label <?php echo esc_attr( $wdm_instructor_access ? '' : 'no-access' ); ?>">
							<input type="checkbox" <?php echo esc_attr( $instructor_role_status ); ?> name="wrld-menu-access-setting-wdm-instructor" id="wrld-menu-access-setting-wdm-instructor" class="dashicons" <?php checked( $wdm_instructor_access ); ?>>
							<span class="<?php echo esc_attr( $instructor_role_status ); ?>"><?php esc_html_e( 'Instructor role by WisdmLabs', 'learndash-reports-by-wisdmlabs' ); ?></span>
							<p class='wrld-access-status wrld-access-status-enabled wrld-wisdm-instructor-enabled' style='<?php echo esc_attr( self::style_display( $wdm_instructor_access && 'disabled' !== $instructor_role_status, 'inline-block' ) ); ?>'><span class="dashicons dashicons-yes"></span><span><?php esc_html_e( 'Access Active', 'learndash-reports-by-wisdmlabs' ); ?></span></p>
							<p class='wrld-access-status wrld-access-status-disabled wrld-wisdm-instructor-disabled' style='<?php echo esc_attr( self::style_display( ! $wdm_instructor_access && 'disabled' !== $instructor_role_status, 'inline-block' ) ); ?>'><span class="dashicons dashicons-no"></span><span><?php esc_html_e( 'Access Inactive', 'learndash-reports-by-wisdmlabs' ); ?></span></p>
							<?php
							if ( 'disabled' === $instructor_role_status ) {
								?>
										<span><a href="https://wisdmlabs.com/instructor-role-for-learndash/?utm_source=wrld&utm_medium=wrld_in_plugin_settings_tab&utm_campaign=wrld_in_plugin_settings_tab&utm_id=20062022&utm_term=wrld_in_plugin_settings_tab" target='_blank'><?php esc_html_e( 'Learn more', 'learndash-reports-by-wisdmlabs' ); ?></a></span>
									<?php
							}
							?>
						</label>
					</div>
				</div>
			<?php
		}

	}
}
