<?php
/**
 * Plugin Name:       WISDM Reports for LearnDash FREE
 * Plugin URI:        https://wisdmlabs.com/reports-for-learndash/
 * Description:       LearnDash Reports By WisdmLabs
 * Version:           1.2.0
 * Requires at least: 5.2
 * Requires PHP:      7.4
 * Author:            WisdmLabs
 * Author URI:        https://wisdmlabs.com/
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       learndash-reports-by-wisdmlabs
 * Domain Path:       /languages
 *
 * @package learndash-reports-by-wisdmlabs
 */

if ( ! defined( 'WRLD_REPORTS_FILE' ) ) {
	define( 'WRLD_REPORTS_FILE', __FILE__ );
}

if ( ! defined( 'WRLD_PLUGIN_VERSION' ) ) {
	define( 'WRLD_PLUGIN_VERSION', '1.2.0' );
}

if ( ! defined( 'WRLD_RECOMENDED_LDRP_PLUGIN_VERSION' ) ) {
	define( 'WRLD_RECOMENDED_LDRP_PLUGIN_VERSION', '1.2.0' );
}

// Constant for text domain.
if ( ! defined( 'WRLD_REPORTS_PATH' ) ) {
	define( 'WRLD_REPORTS_PATH', untrailingslashit( plugin_dir_path( __FILE__ ) ) );
}

if ( ! defined( 'WRLD_REPORTS_SITE_URL' ) ) {
	/**
	 * The constant CSP_PLUGIN_SITE_URL contains the url path to the plugin directory
	 * eg. https://example.com/wp-content/plugins/block-sample/
	 */
	define( 'WRLD_REPORTS_SITE_URL', untrailingslashit( plugins_url( '/', WRLD_REPORTS_FILE ) ) );
}

if ( ! defined( 'WRLD_COURSE_TIME_FREQUENCY' ) ) {
	/**
	 * This constant defines the frequency at which the activity time is being saved in database.
	 */
	define( 'WRLD_COURSE_TIME_FREQUENCY', 30 ); // Define in seconds.
}

if ( ! defined( 'WRLD_COURSE_SESSION_TIMEOUT' ) ) {
	/**
	 * This constant defines the active session timeout for the current activity time-tracking.
	 */
	define( 'WRLD_COURSE_SESSION_TIMEOUT', 30 * MINUTE_IN_SECONDS ); // Define in seconds.
}

if ( ! function_exists( 'wrld_plugin_activation' ) ) {
	function wrld_plugin_activation() {
		$plugin_first_activation = get_option( 'wrld_free_plugin_first_activated', false );
		if ( ! $plugin_first_activation ) {
			update_option(
				'wrld_free_plugin_first_activated',
				array(
					'installed_on' => time(),
					'version'      => WRLD_PLUGIN_VERSION,
				)
			);
		}
	}
}

if ( ! function_exists( 'wrld_add_admin_menus' ) ) {
	function wrld_add_admin_menus() {
		include_once WRLD_REPORTS_PATH . '/includes/admin/dashboard/class-dashboard.php';
		new \WRLDAdmin\Dashboard();
	}
}


if ( ! function_exists( 'wrld_register_blocks' ) ) {
	/**
	 * Registers all the supported blocks in the plugin
	 */
	function wrld_register_blocks() {
		if ( defined( 'LEARNDASH_VERSION' ) ) {
			add_filter( 'block_categories_all', 'wrld_add_custom_block_category', 10, 2 );
			wp_register_script( 'wrld-common-script', WRLD_REPORTS_SITE_URL . '/includes/blocks/src/commons/common-functions.js', array(), WRLD_PLUGIN_VERSION, true );
			$common_data = wrld_get_common_script_localized_data();
			wp_localize_script( 'wrld-common-script', 'wisdm_ld_reports_common_script_data', $common_data );
			include_once WRLD_REPORTS_PATH . '/includes/blocks/registry/class-wrld-register-block-types.php';
			new WisdmReportsLearndashBlockRegistry\WRLD_Register_Block_Types();
		}
	}
}

if ( ! function_exists( 'wrld_add_custom_block_category' ) ) {
	/**
	 * Creates the custom block category in the block registery, this will later be useful to categorize
	 * the blocks added by our plugin
	 *
	 * @param array  $block_categories existing block categories.
	 * @param string $editor_context context.
	 */
	function wrld_add_custom_block_category( $block_categories, $editor_context ) {
		if ( ! empty( $editor_context->post ) ) {
			array_push(
				$block_categories,
				array(
					'slug'  => 'wisdm-learndash-reports',
					'title' => __( 'LearnDash Reports', 'learndash-reports-by-wisdmlabs' ),
					'icon'  => null,
				)
			);
		}
		return $block_categories;
	}
}

if ( ! function_exists( 'wrld_register_patterns' ) ) {
	/**
	 * Registers the defaut pattern of blocks for the reports plugin
	 */
	function wrld_register_patterns() {
		global $wrld_pattern;
		$pattern      = array(
			'title'       => __( 'Default report pattern', 'learndash-reports-by-wisdmlabs' ),
			'description' => __( 'This pattern can be used as the', 'learndash-reports-by-wisdmlabs' ),
			'categories'  => array( 'wisdm-ld-reports' ),
			'content'     => '<!-- wp:columns {"className":"wrld-mw-1400"} -->
			<div class="wp-block-columns wrld-mw-1400"><!-- wp:column {"width":"","className":"lr-top-tiles"} -->
			<div class="wp-block-column lr-top-tiles"><!-- wp:wisdm-learndash-reports/date-filters -->
			<div class="wp-block-wisdm-learndash-reports-date-filters"><div class="wisdm-learndash-reports-chart-block"><div class="wisdm-learndash-reports-date-filters front"></div></div></div>
			<!-- /wp:wisdm-learndash-reports/date-filters -->
			
			<!-- wp:columns {"className":"lr-tiles-container"} -->
			<div class="wp-block-columns lr-tiles-container"><!-- wp:column {"className":"lr-tre"} -->
			<div class="wp-block-column lr-tre"><!-- wp:wisdm-learndash-reports/total-revenue-earned -->
			<div class="wp-block-wisdm-learndash-reports-total-revenue-earned"><div class="wisdm-learndash-reports-total-revenue-earned front"></div></div>
			<!-- /wp:wisdm-learndash-reports/total-revenue-earned --></div>
			<!-- /wp:column -->
			
			<!-- wp:column -->
			<div class="wp-block-column"><!-- wp:wisdm-learndash-reports/total-courses -->
			<div class="wp-block-wisdm-learndash-reports-total-courses"><div class="wisdm-learndash-reports-total-courses front"></div></div>
			<!-- /wp:wisdm-learndash-reports/total-courses --></div>
			<!-- /wp:column -->
			
			<!-- wp:column -->
			<div class="wp-block-column"><!-- wp:wisdm-learndash-reports/total-learners -->
			<div class="wp-block-wisdm-learndash-reports-total-learners"><div class="wisdm-learndash-reports-total-learners front"></div></div>
			<!-- /wp:wisdm-learndash-reports/total-learners --></div>
			<!-- /wp:column -->
			
			<!-- wp:column -->
			<div class="wp-block-column"><!-- wp:wisdm-learndash-reports/pending-assignments -->
			<div class="wp-block-wisdm-learndash-reports-pending-assignments"><div class="wisdm-learndash-reports-pending-assignments front"></div></div>
			<!-- /wp:wisdm-learndash-reports/pending-assignments --></div>
			<!-- /wp:column --></div>
			<!-- /wp:columns --></div>
			<!-- /wp:column --></div>
			<!-- /wp:columns -->
			
			<!-- wp:columns {"className":"wrld-mw-1400"} -->
			<div class="wp-block-columns wrld-mw-1400"><!-- wp:column {"className":"wisdm-reports"} -->
			<div class="wp-block-column wisdm-reports"><!-- wp:wisdm-learndash-reports/revenue-from-courses -->
			<div class="wp-block-wisdm-learndash-reports-revenue-from-courses"><div class="wisdm-learndash-reports-revenue-from-courses front"></div></div>
			<!-- /wp:wisdm-learndash-reports/revenue-from-courses -->
			
			<!-- wp:wisdm-learndash-reports/daily-enrollments -->
			<div class="wp-block-wisdm-learndash-reports-daily-enrollments"><div class="wisdm-learndash-reports-daily-enrollments front"></div></div>
			<!-- /wp:wisdm-learndash-reports/daily-enrollments -->
			
			<!-- wp:wisdm-learndash-reports/report-filters -->
			<div class="wp-block-wisdm-learndash-reports-report-filters"><div class="wisdm-learndash-reports-report-filters front"></div></div>
			<!-- /wp:wisdm-learndash-reports/report-filters -->
			
			<!-- wp:wisdm-learndash-reports/time-spent-on-a-course -->
			<div class="wp-block-wisdm-learndash-reports-time-spent-on-a-course"><div class="wisdm-learndash-reports-time-spent-on-a-course"></div></div>
			<!-- /wp:wisdm-learndash-reports/time-spent-on-a-course -->
			
			<!-- wp:wisdm-learndash-reports/course-completion-rate -->
			<div class="wp-block-wisdm-learndash-reports-course-completion-rate"><div class="wisdm-learndash-reports-course-completion-rate front"></div></div>
			<!-- /wp:wisdm-learndash-reports/course-completion-rate -->
			
			<!-- wp:wisdm-learndash-reports/quiz-completion-rate-per-course -->
			<div class="wp-block-wisdm-learndash-reports-quiz-completion-rate-per-course"><div class="wisdm-learndash-reports-quiz-completion-rate-per-course front"></div></div>
			<!-- /wp:wisdm-learndash-reports/quiz-completion-rate-per-course -->
			
			<!-- wp:wisdm-learndash-reports/quiz-completion-time-per-course -->
			<div class="wp-block-wisdm-learndash-reports-quiz-completion-time-per-course"><div class="wisdm-learndash-reports-quiz-completion-time-per-course front"></div></div>
			<!-- /wp:wisdm-learndash-reports/quiz-completion-time-per-course -->
			
			<!-- wp:wisdm-learndash-reports/learner-pass-fail-rate-per-course -->
			<div class="wp-block-wisdm-learndash-reports-learner-pass-fail-rate-per-course"><div class="wisdm-learndash-reports-learner-pass-fail-rate-per-course front"></div></div>
			<!-- /wp:wisdm-learndash-reports/learner-pass-fail-rate-per-course -->
			
			<!-- wp:wisdm-learndash-reports/average-quiz-attempts -->
			<div class="wp-block-wisdm-learndash-reports-average-quiz-attempts"><div class="wisdm-learndash-reports-average-quiz-attempts front"></div></div>
			<!-- /wp:wisdm-learndash-reports/average-quiz-attempts -->
			
			<!-- wp:wisdm-learndash-reports/course-list -->
			<div class="wp-block-wisdm-learndash-reports-course-list"><div class="wisdm-learndash-reports-course-list"></div></div>
			<!-- /wp:wisdm-learndash-reports/course-list -->
			
			<!-- wp:wisdm-learndash-reports/quiz-reports -->
			<div class="wp-block-wisdm-learndash-reports-quiz-reports"><div id="wisdm-learndash-reports-quiz-report-view" class="wisdm-learndash-reports-quiz-reports">[ldrp_quiz_reports]</div></div>
			<!-- /wp:wisdm-learndash-reports/quiz-reports --></div>
			<!-- /wp:column --></div>
			<!-- /wp:columns -->',
		);
		$wrld_pattern = $pattern['content'];
		register_block_pattern( 'wisdm-learndash-reports/default-report-pattern', $pattern );
	}
}

if ( ! function_exists( 'wrld_create_patterns_page' ) ) {
	/**
	 * On the first activation of the plugin this function creates a new page with the
	 * reports pattern if not exists.
	 */
	function wrld_create_patterns_page( $force_create = false ) {
		if ( ! get_option( 'ldrp_reporting_page', false ) || $force_create ) {
			global $wrld_pattern;
			$page = wp_insert_post(
				array(
					'post_title'   => 'Reports Dashboard',
					'post_name'    => 'reporting-dashboard',
					'post_content' => $wrld_pattern,
					'post_status'  => 'draft',
					'post_type'    => 'page',
				)
			);
			if ( ! is_wp_error( $page ) ) {
				update_option( 'ldrp_reporting_page', $page );
			}
		}
	}
}

if ( ! function_exists( 'wrld_register_pattern_category' ) ) {
	/**
	 * Registers the new custom category to categorize the newly added block patterns by the plugin
	 */
	function wrld_register_pattern_category() {
		register_block_pattern_category(
			'wisdm-ld-reports',
			array( 'label' => __( 'LearnDash Reports', 'learndash-reports-by-wisdmlabs' ) )
		);
	}
}

if ( ! function_exists( 'wrld_register_apis' ) ) {
	/**
	 * The function registers all the API endpoints written to fetch the data from the server.
	 */
	function wrld_register_apis() {
		if ( defined( 'LEARNDASH_VERSION' ) ) {
			include_once WRLD_REPORTS_PATH . '/includes/apis/class-wrld-learndash-endpoints.php';
			$endpoint_entry = WRLD_LearnDash_Endpoints::get_instance();
		}
	}
}
if ( ! function_exists( 'wrld_load_admin_functions' ) ) {
	/**
	 * The function includes the admin related functions.
	 */
	function wrld_load_admin_functions() {
		if ( defined( 'LEARNDASH_VERSION' ) ) {
			include_once WRLD_REPORTS_PATH . '/includes/admin/class-admin-functions.php';
		}
	}
}

if ( ! function_exists( 'wrld_db_install' ) ) {
	/**
	 * The functions is called on the install to create the databases required.
	 *
	 * TODO: Remove if no longer required. @JD
	 */
	function wrld_db_install() {
		global $wpdb;
		global $wrld_db_version;

		$table_name = $wpdb->prefix . 'ld_time_entries';

		$charset_collate = $wpdb->get_charset_collate();
		if ( $wpdb->get_var( $wpdb->prepare( 'SHOW TABLES LIKE %s', $wpdb->esc_like( $table_name ) ) ) === $table_name ) {
			return;
		}
		$sql = 'CREATE TABLE ' . $table_name . " (
				id bigint(20) unsigned NOT NULL AUTO_INCREMENT,
				course_id bigint(20) unsigned NOT NULL DEFAULT '0',
				post_id bigint(20) unsigned NOT NULL DEFAULT '0',
				user_id bigint(20) unsigned NOT NULL DEFAULT '0',
				activity_updated int(11) unsigned DEFAULT NULL,
				time_spent bigint(20) unsigned DEFAULT NULL,
				ip_address VARCHAR(100) NULL DEFAULT '',
			  	PRIMARY KEY  (id),
			  	KEY user_id (user_id),
			  	KEY post_id (post_id),
				KEY course_id (course_id),
			  	KEY activity_updated (activity_updated)
				) " . $charset_collate . ';';
		if ( ! function_exists( 'dbDelta' ) ) {
			require_once ABSPATH . 'wp-admin/includes/upgrade.php';
		}
		dbDelta( $sql );

		add_option( 'wrld_db_version', $wrld_db_version );
	}
}

if ( ! function_exists( 'wrld_enqueue_global_styles' ) ) {
	/**
	 * Enques the commonly required stylesheet by the plugin
	 */
	function wrld_enqueue_global_styles() {
		wp_enqueue_style( 'wrld_global_styles', plugins_url( 'assets/css/style.css', __FILE__ ), array(), WRLD_PLUGIN_VERSION );
	}
}

if ( ! function_exists( 'wrld_learndash_dependency_check' ) ) {
	/**
	 * Checks if all the available dependancies are present.
	 */
	function wrld_learndash_dependency_check() {
		// check if learndash is active.
		if ( ! defined( 'LEARNDASH_VERSION' ) ) {
			unset( $_GET['activate'] );
			add_action( 'admin_notices', 'wrld_activation_notices' );
		}
	}
}

if ( ! function_exists( 'wrld_activation_notices' ) ) {
	/**
	 * Displays the notice on the activation, the function is called when the parent plugin is inactive.
	 */
	function wrld_activation_notices() {
		echo "<div class='error'>
			<p>LearnDash LMS plugin is not active. In order to make <strong>WISDM Reports for LearnDash </strong> plugin work, you need to install and activate LearnDash LMS first.</p>
		</div>";
	}
}

if ( ! function_exists( 'wrld_nonlogged_in_user_block' ) ) {
	/**
	 * This function blocks the non-logged in user from accessing the reports page.
	 *
	 * @param string $content wp-post content.
	 */
	function wrld_nonlogged_in_user_block( $content ) {
		$fallback_template = WRLD_REPORTS_PATH . '/includes/templates/guest-message.php';
		$template          = apply_filters( 'wrld-get-guest-template-path', $fallback_template );

		if ( file_exists( $template ) ) {
			include_once $template;
		} else {
			include_once $fallback_template;
		}

		$content = wrld_get_guest_message_on_reports_page( $content );

		return $content;
	}
}

if ( ! function_exists( 'wrld_load_textdomain' ) ) {
	/**
	 * Load plugin textdomain.
	 */
	function wrld_load_textdomain() {
		load_plugin_textdomain( 'learndash-reports-by-wisdmlabs', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
	}
}

if ( ! function_exists( 'wrld_welcome_modal' ) ) {
	/**
	 * This function is used to show the welcome message on first visit to the reports dashboard page.
	 */
	function wrld_welcome_modal( $content ) {
		global $post;
		$auto_generated_page = get_option( 'ldrp_reporting_page', 0 );
		$visited_dashboard   = get_option( 'wrld_visited_dashboard', false );

		if ( is_admin() || $post->ID != $auto_generated_page || defined( 'REST_REQUEST' ) || ! current_user_can( 'manage_options' ) ) {
			return $content;
		}

		if ( ! defined( 'DOING_AJAX' ) || ! DOING_AJAX ) {
			if ( false === $visited_dashboard || 'pro' !== $visited_dashboard ) {
				wp_enqueue_style( 'wrld_welcome_modal_style', plugins_url( 'assets/css/wrld-welcome-modal.css', __FILE__ ), array(), WRLD_PLUGIN_VERSION );
				wp_enqueue_script( 'wrld_welcome_modal_script', plugins_url( 'assets/js/wrld-welcome-modal.js', __FILE__ ), array( 'jquery' ), WRLD_PLUGIN_VERSION, true );
				$local_script_data = array(
					'wp_ajax_url' => admin_url( 'admin-ajax.php' ),
					'nonce'       => wp_create_nonce( 'wrld-welcome-modal' ),
				);
				wp_localize_script( 'wrld_welcome_modal_script', 'wrld_welcome_modal_script_data', $local_script_data );
				include_once WRLD_REPORTS_PATH . '/includes/templates/welcome-modal.php';
				if ( ! defined( 'LDRP_PLUGIN_VERSION' ) && 'free' !== $visited_dashboard ) {
					$content = $content . wrld_free_get_popup_modal_content();
					//update_option( 'wrld_visited_dashboard', 'free' );
				} elseif ( defined( 'LDRP_PLUGIN_VERSION' ) && ( false === $visited_dashboard || 'free' === $visited_dashboard ) ) {
					$content = $content . wrld_pro_get_popup_modal_content();
					//update_option( 'wrld_visited_dashboard', 'pro' );
				}
			}
			return $content;
		}
	}
}

if ( ! function_exists( 'wrld_free_onboarding_modal' ) ) {
	function wrld_free_onboarding_modal() {

		if ( defined( 'LDRP_PLUGIN_VERSION' ) ) {
			return; //pro version is active
		}

		$screen = get_current_screen();

		if ( ! empty( $screen ) && 'plugins' !== $screen->base && 'update' !== $screen->base ) {
			return; //not on admin plugins page
		}

		$visited_settings_page = get_option( 'wrld_settings_page_visited', false );
		if ( false !== $visited_settings_page ) {
			return; //user knows about setting page.
		}

		if ( ! defined( 'DOING_AJAX' ) || ! DOING_AJAX ) {
			wp_enqueue_style( 'wrld_modal_style', plugins_url( 'assets/css/wrld-modal.css', __FILE__ ), array(), WRLD_PLUGIN_VERSION );
			wp_enqueue_script( 'wrld_modal_script', plugins_url( 'assets/js/wrld-modal.js', __FILE__ ), array( 'jquery' ), WRLD_PLUGIN_VERSION );
			wp_localize_script( 'wrld_modal_script', 'wrld_modal_script_object', array( 'wp_ajax_url' => admin_url( 'admin-ajax.php' ) ) );
			$modal_head              = __( 'Welcome to WISDM Reports FREE for LearnDash!', 'learndash-reports-by-wisdmlabs' );
			$modal_description       = __( 'Plugin Activation Successful. You are just a few steps away from launching your Reports Dashboard.', 'learndash-reports-by-wisdmlabs' );
			$info_url                = 'admin.php?page=wrld-dashboard-page';
			$modal_action_text       = __( 'Let\'s get started!', 'learndash-reports-by-wisdmlabs' );
			$action_close            = '';
			$plugin_first_activation = get_option( 'wrld_free_plugin_first_activated', false );

			if ( $plugin_first_activation && ! is_array( $plugin_first_activation ) ) {
				//pluginu updated to v1.2.0
				$modal_description = __( 'The plugin has been updated successfully.', 'learndash-reports-by-wisdmlabs' );
				$modal_action_text = __( 'Go Ahead!', 'learndash-reports-by-wisdmlabs' );
			}

			$wp_nonce = wp_create_nonce( 'reports-firrst-install-modal' );
			include_once WRLD_REPORTS_PATH . '/includes/templates/admin-modal.php';
		}
	}
}

if ( ! function_exists( 'wrld_free_upgrade_to_pro_modal' ) ) {
	function wrld_free_upgrade_to_pro_modal() {
		if ( ! defined( 'LDRP_PLUGIN_VERSION' ) ) {
			return; //pro version is active
		}

		$screen = get_current_screen();
		if ( ! empty( $screen ) && 'plugins' !== $screen->base && 'update' !== $screen->base ) {
			return; //not on admin plugins page
		}

		if ( version_compare( LDRP_PLUGIN_VERSION, WRLD_RECOMENDED_LDRP_PLUGIN_VERSION, '>=' ) ) {
			return; //latest or recomendnded pro version is installed.
		}

		if ( ! defined( 'DOING_AJAX' ) || ! DOING_AJAX ) {
			//show modal asking for update
			wp_enqueue_style( 'wrld_modal_style', plugins_url( 'assets/css/wrld-modal.css', __FILE__ ), array(), WRLD_PLUGIN_VERSION );
			wp_enqueue_script( 'wrld_modal_script', plugins_url( 'assets/js/wrld-modal.js', __FILE__ ), array( 'jquery' ), WRLD_PLUGIN_VERSION );
			wp_localize_script( 'wrld_modal_script', 'wrld_modal_script_object', array( 'wp_ajax_url' => admin_url( 'admin-ajax.php' ) ) );
			$modal_head              = __( 'Welcome to WISDM Reports FREE for LearnDash!', 'learndash-reports-by-wisdmlabs' );
			$modal_description       = __( 'The plugin has been updated successfully. You are a few steps away from launching the Reports Dashboard. The next step is to update the WISDM Reports PRO for LearnDash plugin on the “All Plugins” Page of your WordPress dashboard', 'learndash-reports-by-wisdmlabs' );
			$info_url                = '#';
			$modal_action_text       = __( 'Got It!', 'learndash-reports-by-wisdmlabs' );
			$action_close            = 'update-pro';
			$plugin_first_activation = get_option( 'wrld_free_plugin_first_activated', false );
			$wp_nonce                = wp_create_nonce( 'reports-firrst-install-modal' );
			include_once WRLD_REPORTS_PATH . '/includes/templates/admin-modal.php';
		}
	}
}

if ( ! function_exists( 'wrld_add_review_notice' ) ) {
	/**
	 * To display the notice to participate in the survey.
	 */
	function wrld_add_review_notice() {
		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}

		$review_dismissed        = get_option( 'ld-reports-review-dismissed', false );
		$plugin_first_activation = get_option( 'wrld_free_plugin_first_activated', false );
		$skipped_on              = get_option( 'wrld_last_skipped_on', false );

		if ( $plugin_first_activation && is_array( $plugin_first_activation ) ) {
			$plugin_first_activation = $plugin_first_activation['installed_on'];
		}

		if ( $skipped_on && time() - (int) $skipped_on < 259200 ) {
			//skipped less than three days back.
			return;
		}

		$show_review_notification = $plugin_first_activation && ( time() - $plugin_first_activation > 604800 ) ? true : false;

		if ( ! $show_review_notification || $review_dismissed ) {
			return;
		}

		$message_head = __( 'You have been using WISDM Reports for LearnDash for over a week now!', 'learndash-reports-by-wisdmlabs' );
		$message      = __( 'Helping other users is our motivation and if you could give us a 5 star rating on WordPress, that would help other users make an informed decision while choosing WISDM Reports and it would mean the world to us!', 'learndash-reports-by-wisdmlabs' );
		$button_text  = __( 'Okay, you deserve it', 'learndash-reports-by-wisdmlabs' );
		$link         = 'https://wordpress.org/support/plugin/wisdm-reports-for-learndash/reviews/#new-post';
		wrld_show_review_notice( $message_head, $message, $button_text, $link );
	}
}

if ( ! function_exists( 'wrld_add_upgrade_notice' ) ) {
	function wrld_add_upgrade_notice() {
		if ( ! current_user_can( 'manage_options' ) ) {
			return;
		}
		if ( \WisdmReportsLearndash\Admin_Functions::is_plugin_installed( 'learndash-reports-pro/learndash-reports-pro.php' ) ) {
			return;
		}

		if ( isset( $_GET['ld-reports-upgrade-skip'] ) && true == sanitize_text_field( wp_unslash( $_GET['ld-reports-upgrade-skip'] ) ) ) {
			update_option( 'ld-reports-upgrade-skip', gmdate( 'U' ) );
			return;
		}
		$upgrade_status = get_option( 'ld-reports-upgrade-skip', false );
		if ( false != $upgrade_status ) {
			return;
		}

		$message_head      = __( 'Some of your students might be falling behind on their course and quiz performance!', 'learndash-reports-by-wisdmlabs' );
		$message           = __( 'To know which students are performing poorly on quizzes, upgrade to our Pro version today. It has a lot of other interesting insights for you!', 'learndash-reports-by-wisdmlabs' );
		$button_text       = __( 'UPGRADE TO PRO', 'learndash-reports-by-wisdmlabs' );
		$link              = 'https://wisdmlabs.com/reports-for-learndash/#pricing';
		$wisdm_logo        = WRLD_REPORTS_SITE_URL . '/assets/images/wisdmlabs.png';
		$dismiss_attribute = 'ld-reports-upgrade-skip';
		wp_enqueue_style( 'wrld_upgrade_notices_style', plugins_url( 'assets/css/notices.css', __FILE__ ), array(), WRLD_PLUGIN_VERSION );
		include WRLD_REPORTS_PATH . '/includes/templates/notice.php';
	}
}

if ( ! function_exists( 'wrld_add_recomendation_notice' ) ) {
	function wrld_add_recomendation_notice() {
		if ( current_user_can( 'manage_options' ) && defined( 'LDRP_PLUGIN_VERSION' ) && version_compare( LDRP_PLUGIN_VERSION, WRLD_RECOMENDED_LDRP_PLUGIN_VERSION, '<' ) ) {
			wp_enqueue_script( 'ldrp_update_script', plugins_url( 'assets/js/wrld-update.js', __FILE__ ), array( 'jquery', 'updates' ), LDRP_PLUGIN_VERSION );
			$plugin_dir       = LDRP_PLUGIN_DIR;
			$plugin_basename  = plugin_basename( LDRP_PLUGIN_DIR . 'learndash-reports-pro.php' );
			$license_inactive = '';
			$screen           = get_current_screen();
			$license_page     = '';
			$on_plugins_page  = 'plugins' === $screen->base ? 'yes' : 'no';

			$cta_message_part_1 = '';
			$cta_message_action = '';
			$cta_message_part_2 = '';

			$validity = get_option( 'edd_learndash-reports-pro_license_status', false );
			if ( 'valid' !== $validity ) {
				$license_inactive   = 'license-inactive';
				$cta_message_part_1 = __( 'Your License Key for the plugin seems to be inactive. Kindly "Activate" the License Key from ', 'learndash-reports-by-wisdmlabs' );
				$cta_message_action = __( 'here', 'learndash-reports-by-wisdmlabs' );
				$cta_message_part_2 = __( ' and then proceed to update the WISDM Reports PRO plugin.', 'learndash-reports-by-wisdmlabs' );

				$license_page = admin_url( 'admin.php?page=wisdmlabs-licenses' );
				if ( 'toplevel_page_wisdmlabs-licenses' === $screen->base ) {
					return;
				}
			}
			?>
			<div class='notice-error notice is-dismissible'>
				<div style='display:inline-flex; justify-content:center; align-items:center;' class='wrld-plugin-dependency-installation'>
					<p>
						<strong>
						<?php echo wp_kses_post( __( 'WisdmLabs recommends you to update the WISDM Reports PRO for LearnDash to its latest version now.', 'learndash-reports-by-wisdmlabs' ) ); ?>
						</strong>
						<?php
						if ( ! empty( $license_inactive ) ) {
							?>
								<span><?php echo esc_html( $cta_message_part_1 ); ?></span>
								<a href=<?php echo esc_attr( $license_page ); ?>><?php echo esc_html( $cta_message_action ); ?></a>
								<span><?php echo esc_html( $cta_message_part_2 ); ?></span>
								<?php
						} else {
							?>
							<a id="wrld-plugin-update-notice" data-on_plugins_page="<?php echo esc_attr( $on_plugins_page ); ?>" data-pluginspage="<?php echo esc_attr( admin_url( 'plugins.php' ) ); ?>" data-basename="<?php echo esc_attr( $plugin_basename ); ?>" href="#"><?php esc_html_e( 'Update Now', 'learndash-reports-by-wisdmlabs' ); ?></a>
							<span id="wrld-plugin-update-notice-spinner" data-updating="<?php esc_attr_e( 'Updating...', 'learndash-reports-by-wisdmlabs' ); ?>" data-failed_message="<?php esc_attr_e( 'Plugin update failed, we request you to update the plugin manually. if you still face any issues feel free to reach out to us at helpdesk@wisdmlabs.com', 'learndash-reports-by-wisdmlabs' ); ?>" style="margin-top:0px;" class="spinner"></span>
							<span id="wrld-plugin-update-notice-status"></span>
							<?php
						}
						?>
					</p>
				</div>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'wrld_show_review_notice' ) ) {
	/**
	 * This function returns the html code for the Review Notice
	 *
	 * @since 1.0.1
	 * @param string $message_head Notification heading.
	 * @param string $message Notification message body.
	 * @param string $button_text Text to be displayed on the action button in the notification.
	 * @param string $link Link for the action button in the notification default to wisdmlabs.com.
	 * @return void
	 */
	function wrld_show_review_notice( $message_head, $message, $button_text, $link = 'https://wordpress.org/support/plugin/wisdm-reports-for-learndash/reviews/#new-post' ) {
		$wisdm_logo        = WRLD_REPORTS_SITE_URL . '/assets/images/wisdmlabs.png';
		$dismiss_attribute = 'ld-reports-review-skip';
		$wp_nonce          = wp_create_nonce( 'wrld-review-notice' );
		wp_enqueue_style( 'wrld_notices_style', plugins_url( 'assets/css/review-notification.css', __FILE__ ), array(), WRLD_PLUGIN_VERSION );
		wp_enqueue_script( 'wrld_notice_script', plugins_url( 'assets/js/wrld-notices.js', __FILE__ ), array( 'jquery' ), WRLD_PLUGIN_VERSION );
		wp_localize_script( 'wrld_notice_script', 'wrld_modal_script_object', array( 'wp_ajax_url' => admin_url( 'admin-ajax.php' ) ) );
		include WRLD_REPORTS_PATH . '/includes/templates/review-notification.php';
	}
}

if ( ! function_exists( 'wrld_get_common_script_localized_data' ) ) {
	/**
	 * This function is used to generate the commonly used localized data for the common script used by all the blocks.
	 */
	function wrld_get_common_script_localized_data() {
		$report_type = 'default-ld-reports';
		if ( isset( $_GET['ld_report_type'] ) && 'quiz-reports' == $_GET['ld_report_type'] ) {
			$report_type = 'quiz-reports';
		}
		if ( ( isset( $_GET['screen'] ) && 'quiz' == $_GET['screen'] ) || isset( $_GET['pageno'] ) ) {
			$report_type = 'quiz-reports';
		}
		$currency = function_exists( 'learndash_get_currency_symbol' ) ? learndash_get_currency_symbol() : '';
		$currency = empty( $currency ) && function_exists( 'learndash_30_get_currency_symbol' ) ? @learndash_30_get_currency_symbol() : $currency;
		$currency = empty( $currency ) ? '$' : $currency;

		$auto_generated_page       = get_option( 'ldrp_reporting_page', false );
		$visited_dashboard         = get_option( 'wrld_visited_dashboard', false );
		$page_configuration_status = false;
		if ( $auto_generated_page && $auto_generated_page > 0 && ( isset( $_GET['post'] ) && $auto_generated_page == $_GET['post'] ) ) {
			$page_configuration_status = 'publish' !== get_post_status( $auto_generated_page );
		}
		$data = array(
			'plugin_asset_url'          => WRLD_REPORTS_SITE_URL . '/assets',
			'is_pro_version_active'     => apply_filters( 'wisdm_ld_reports_pro_version', false ),
			'upgrade_link'              => 'https://wisdmlabs.com/reports-for-learndash/?utm_source=google&utm_term=FreeToPro',
			'is_admin_user'             => current_user_can( 'manage_options' ),
			'currency_in_use'           => apply_filters( 'wrld_currency_in_use', $currency ),
			'report_type'               => $report_type,
			'ajaxurl'                   => admin_url( 'admin-ajax.php' ),
			'report_nonce'              => wp_create_nonce( 'wisdm_ld_reports_page' ),
			'start_date'            => apply_filters( 'wrld_filter_start_date', date( 'j M Y H:i:s', strtotime( gmdate( 'j M Y' ) . '-30 days' ) ) ),// phpcs:ignore.
			'end_date'              => apply_filters( 'wrld_filter_end_date', date( 'j M Y H:i:s', current_time( 'timestamp' ) ) ),// phpcs:ignore.
			'ld_custom_labels'          => wrld_get_custom_ld_labels(),
			'is_demo'                   => apply_filters( 'wrld_is_demo_enabled', false ),
			'dashboard_page_id'         => $auto_generated_page,
			'page_configuration_status' => $page_configuration_status,
			'visited_dashboard'         => $visited_dashboard,
			'notice_content'            => array(
												'header' => __( 'You are one step away from launching your Reports Dashboard.', 'learndash-reports-by-wisdmlabs' ),
												'li_1'   => __( 'Each Reporting component seen below is a Gutenberg block. They can be found by clicking on the "+" icon (block inserter)', 'learndash-reports-by-wisdmlabs' ),
												'li_2'   => __( 'The dashboard below is preconfigured. You can also hide/show/reorder the blocks and reuse the same pattern below.', 'learndash-reports-by-wisdmlabs' ),
												'li_3'   => __( 'Once launched, only the admin can access this page. To provide access to others, navigate to the WordPress dashboard > Wisdm Reports > Settings tab.', 'learndash-reports-by-wisdmlabs' ),
											),
		);
		return $data;
	}
}


if ( ! function_exists( 'wrld_get_custom_ld_labels' ) ) {
	/**
	 * This function when called checks if the custom labels are defined in the learndash settings and returns the
	 * array of custom labels with label keys.
	 *
	 * @return array $result array of custom labels with label keys.
	 */
	function wrld_get_custom_ld_labels() {
		$labels = array( 'course', 'courses', 'quiz', 'quizzes', 'lesson', 'lessons', 'topic', 'topics', 'question', 'questions', 'group', 'groups' );
		$result = array();
		foreach ( $labels as $label ) {
			$result[ $label ] = \LearnDash_Custom_Label::get_label( $label );
		}
		return $result;
	}
}

if ( ! function_exists( 'wrld_register_admin_ajax_callbacks' ) ) {
	function wrld_register_admin_ajax_callbacks() {
		$auto_generated_page         = get_option( 'ldrp_reporting_page', false );
		$visited_auto_generated_page = (bool) get_option( 'wrld_reporting_page_visited', true );
		include_once WRLD_REPORTS_PATH . '/includes/admin/class-admin-functions.php';
		add_action( 'wp_ajax_wrld_page_visit', '\WisdmReportsLearndash\Admin_Functions::update_reporting_page_visit' );
		// add_action( 'wp_ajax_wrld_notice_action', '\WisdmReportsLearndash\Admin_Functions::wrld_notice_action' );

		$wrld_pages = array( 'wrld-dashboard-page', 'wrld-license-activation', 'wrld-other-plugins', 'wrld-help', 'wrld-settings' );
		if ( is_admin() && ( ! defined( 'DOING_AJAX' ) || ! DOING_AJAX ) && ( ! isset( $_GET['page'] ) || ! in_array( sanitize_text_field( $_GET['page'] ), $wrld_pages ) ) ) {
			$settings_data = get_option( 'wrld_settings', array() );
			unset( $settings_data['skip-license-activation'] );
			update_option( 'wrld_settings', $settings_data );
			//var_dump($settings_data);exit();
		}
	}
}

if ( ! function_exists( 'wrld_add_page_to_primary_menu' ) ) {
	/**
	 * This function adds the link to the autogenerated reports page to the primary menu
	 * only when the page is published & configuration set to show the menu automatically
	 * in the primary menu.
	 */
	function wrld_add_page_to_primary_menu( $items, $args ) {
		$settings_data = get_option( 'wrld_settings', false );
		$wrld_page     = get_option( 'ldrp_reporting_page', false );
		if ( $settings_data && isset( $settings_data['wrld-menu-config-setting'] ) && $settings_data['wrld-menu-config-setting'] && $wrld_page && $wrld_page > 0 ) {
			if ( 'publish' === get_post_status( $wrld_page ) ) {
				if ( 'primary' == $args->theme_location ) {
					$items .= '<li id="menu-item-" ' . $wrld_page . ' class="menu-item menu-item-type-custom" ><a href="' . get_post_permalink( $wrld_page ) . '">' . __( 'Reports Dashboard', 'learndash-reports-by-wisdmlabs' ) . '</a></li>';
				}
			}
		}
		return $items;
	}
}

if ( ! function_exists( 'wrld_dashboad_link' ) ) {
	function wrld_dashboad_link() {
		ob_start();
		$wrld_page = get_option( 'ldrp_reporting_page', false );
		if ( false != $wrld_page && $wrld_page > 0 ) {
			$link = get_post_permalink( $wrld_page );
			?>
			<a class='wrld-dashboard-link' href=<?php echo esc_attr( $link ); ?>>
				<button class='button wrld-dashboard-link-btn'><?php esc_html_e( 'Reports Dashboard', 'learndash-reports-by-wisdmlabs' ); ?></button>
			</a>
			<?php
		}
		$content = ob_get_contents();
		ob_end_clean();
		return $content;
	}
}

if ( ! function_exists( 'wisdm_reports_free_multi_installation_check' ) ) {
	/**
	 * This function will check if the multiple instances of the plugin WISDM reports for lerandash are active on the site
	 * In case of multiple instances it will deactivate the plugin which was installed from wisdmlabs.
	 */
	function wisdm_reports_free_multi_installation_check() {
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
		$installed_plugins       = get_plugins();
		$installed_and_activated = false;
		$free_plugin_uris        = array( 'learndash-reports-by-wisdmlabs', 'learndash-reports-by-wisdmlabs' );
		foreach ( $installed_plugins as $key => $plugin_data ) {
			if ( in_array( $plugin_data['TextDomain'], $free_plugin_uris, true ) ) {
				if ( isset( $plugin_data['UpdateURI'] ) && 'https://wisdmlabs.com' == $plugin_data['UpdateURI'] ) {
					deactivate_plugins( $key );
					break;
				}
			}
		}
	}
}

add_action( 'plugins_loaded', 'wrld_load_textdomain' );
add_action( 'plugins_loaded', 'wisdm_reports_free_multi_installation_check', 1 );
add_action( 'init', 'wrld_add_admin_menus', 96 );
add_action( 'init', 'wrld_register_blocks', 97 );
add_action( 'init', 'wrld_register_pattern_category', 98 );
add_action( 'init', 'wrld_register_patterns', 99 );
add_action( 'init', 'wrld_create_patterns_page', 100 );
//add_action( 'admin_notices', 'wrld_notify_first_report_page_creation', 99 );
add_action( 'admin_notices', 'wrld_free_onboarding_modal', 99 );
add_action( 'admin_notices', 'wrld_free_upgrade_to_pro_modal', 99 );
add_action( 'admin_init', 'wrld_register_admin_ajax_callbacks' );
add_action( 'plugins_loaded', 'wrld_learndash_dependency_check', 1 );
add_action( 'plugins_loaded', 'wrld_register_apis' );
add_action( 'plugins_loaded', 'wrld_load_admin_functions' );
add_action( 'wp_enqueue_scripts', 'wrld_enqueue_global_styles' );
add_action( 'admin_enqueue_scripts', 'wrld_enqueue_global_styles' );
add_filter( 'the_content', 'wrld_nonlogged_in_user_block', 10, 1 );
add_filter( 'the_content', 'wrld_welcome_modal', 11, 1 );
register_activation_hook( WRLD_REPORTS_FILE, 'wrld_db_install' );
register_activation_hook( WRLD_REPORTS_FILE, 'wrld_plugin_activation' );
add_action( 'admin_notices', 'wrld_add_review_notice', 1 );
add_action( 'admin_notices', 'wrld_add_upgrade_notice', 1 );
add_action( 'admin_notices', 'wrld_add_recomendation_notice', 2 );
add_filter( 'wp_nav_menu_items', 'wrld_add_page_to_primary_menu', 10, 2 );
add_shortcode( 'wrld_dashboard_link', 'wrld_dashboad_link' );
